The objective of this project is to create a configuration independent configuration module, easy to use, and that you
know it is easy to add a new backend.

There is a lot of cool stuff pending to be done, and will try to populate issues/TODOs but it's way too much. Feel free
to submit PRs with whatever you want. I will then accept them if they work etc.

TBD: Everything